@@ -92,7 +92,7 @@ Some notes:
 
 =over 5
 
-=item SYNOPSIS
+=item Modules loaded by default
 
 See the SYNOPSIS section at the end of this document for a list of
 modules loaded by default.
@@ -140,13 +140,14 @@ start-up modules.
    use PDL::IO::Misc;
    use PDL::IO::FITS;
    use PDL::IO::Pic;
+   use PDL::IO::Storable;
    use PDL::Lvalue;
 
 =cut
 
 
 # set the version:
-$PDL::VERSION = '2.007';     # Go to sub numbering per git push
+$PDL::VERSION = '2.016';
 
 # Main loader of standard PDL package
 
@@ -180,6 +181,10 @@ use PDL::IO::Pic;           # rpic/wpic
 
 use PDL::Config;
 
+# Load this to avoid mysterious Storable segfaults
+
+use PDL::IO::Storable;
+
 EOD
 
 die $@ if $@;
@@ -191,6 +196,18 @@ die $@ if $@;
 # properly recognizes the PDL package.
 package PDL;
 
+# support: use Inline with => 'PDL';
+# Returns a hash containing parameters accepted by recent versions of
+# Inline, to tweak compilation.  Not normally called by anyone but
+# the Inline API.
+#
+# If you're trying to debug the actual code, you're looking for "IFiles.pm"
+# which is currently in the Core directory. --CED 23-Feb-2015
+sub Inline {
+    require PDL::Install::Files;
+    goto &PDL::Install::Files::Inline;
+}
+
 ##################################################
 # Rudimentary handling for multiple Perl threads #
 ##################################################
